diff --git a/src/xercesc/framework/Wrapper4InputSource.hpp b/src/xercesc/framework/Wrapper4InputSource.hpp
index 9cabed65591f8f91dd73b575941e0b75f862e6dc..4079330384e9fa83bb91ed8397bf995023df6c3b 100644
--- a/src/xercesc/framework/Wrapper4InputSource.hpp
+++ b/src/xercesc/framework/Wrapper4InputSource.hpp
@@ -66,10 +66,10 @@ public:
     /** @name Virtual input source interface */
     //@{
   /**
     * This wrapper doesn't support character streams
     *
     */
-    virtual const XMLCh* getCharacterStream() const;
+    virtual const XMLCh* getStringData() const;
 
   /**
     * Makes the byte stream for this input source.
@@ -147,6 +147,17 @@ public:
     // -----------------------------------------------------------------------
     /** @name Setter methods */
     //@{
+  /**
+    * This wrapper only exposes the given InputSource, no setting allowed
+    *
+    */
+    virtual void setStringData(const XMLCh* data);
+
+  /**
+    * This wrapper only exposes the given InputSource, no setting allowed
+    *
+    */
+    virtual void setByteStream(InputSource* stream);
 
   /**
     * Set the encoding which will be required for use with the XML text read
@@ -254,7 +265,7 @@ inline const XMLCh* Wrapper4InputSource::getBaseURI() const
     return 0; // REVISIT - should we return an empty string?
 }
 
-inline const XMLCh* Wrapper4InputSource::getCharacterStream() const
+inline const XMLCh* Wrapper4InputSource::getStringData() const
 {
     return 0;
 }
@@ -266,6 +277,14 @@ inline void Wrapper4InputSource::setBaseURI(const XMLCh* const)
 {
 }
 
+inline void Wrapper4InputSource::setStringData(const XMLCh*)
+{
+}
+
+inline void Wrapper4InputSource::setByteStream(InputSource*)
+{
+}
+
 XERCES_CPP_NAMESPACE_END
 
 #endif
@@ -66,10 +66,10 @@ public:
     //@{
   /**
-    * This wrapper doesn't support character streams
+    * This wrapper doesn't support string data
     *
     */